@@ -403,10 +403,10 @@ for(GLOBALS->yytext_vcd_partial_c_2[len++]=ch;;GLOBALS->yytext_vcd_partial_c_2[l
 	if(ch<=' ') break;
 	}
 GLOBALS->yytext_vcd_partial_c_2[len]=0;	/* terminator */
+GLOBALS->yylen_vcd_partial_c_2=len;
 
 if(is_string)
 	{
-	GLOBALS->yylen_vcd_partial_c_2=len;
 	return(T_STRING);
 	}
 
@@ -1131,7 +1131,7 @@ for(;;)
                                         }
                                 }
 			T_GET;
-			if(tok==T_STRING)
+			if (tok!= T_END && tok != T_EOF)
 				{
 				struct slist *s;
 				s=(struct slist *)calloc_2(1,sizeof(struct slist));
